@@ -139,9 +139,10 @@ class LeaderboardMixin:
         try:
             file_download_url = file_upload_api.get_download_url(file_key)
         except FileUploadError as exc:
-            logger.exception('FileUploadError: URL retrieval failed for key {file_key} with error {error}'.format(
+            logger.exception(
+                'FileUploadError: URL retrieval failed for key %s with error %s',
                 file_key=file_key,
                 error=exc
-            ))
+            )
             file_download_url = ''
         return file_download_url
